/*
 * Created on 6.2.2006
 *
 */
package cz.muni.fi.pb138.demo.sax;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.MalformedURLException;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParserFactory;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.sax.SAXResult;
import javax.xml.transform.stream.StreamSource;

import org.xml.sax.ContentHandler;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLFilter;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;

public class Demo {

    private File inputFile = new File("demo.xml");

    private File inputFileWithDTD = new File("demo-dtd.xml");

    public void runEchoHandler() throws TransformerException {

        TransformerFactory tf = TransformerFactory.newInstance();

        Transformer transformer = tf.newTransformer();

        Source source = new StreamSource(inputFile);

        ContentHandler ch = new EchoContentHandler();

        Result result = new SAXResult(ch);

        transformer.transform(source, result);
    }

    public void runCounterFilterAndEchoHandler() throws TransformerException,
            SAXException, ParserConfigurationException, MalformedURLException,
            IOException {

        SAXParserFactory factory = SAXParserFactory.newInstance();
        factory.setNamespaceAware(true);

        XMLReader reader = factory.newSAXParser().getXMLReader();

        XMLFilter filter = new CounterFilter();
        filter.setParent(reader);

        filter.setContentHandler(new EchoContentHandler());

        filter.parse(new InputSource(inputFile.toURL().toString()));
    }

    public void runTextExtractionFilter(File f)
            throws TransformerException, SAXException,
            ParserConfigurationException, MalformedURLException, IOException {

        SAXParserFactory factory = SAXParserFactory.newInstance();
        factory.setNamespaceAware(true);

        XMLReader reader = factory.newSAXParser().getXMLReader();

        XMLFilter filter = new TextExtractionFilter();
        filter.setParent(reader);

        filter.setContentHandler(new DefaultHandler());

        filter.parse(new InputSource(f.toURL().toString()));
    }

    public void runDemo() throws TransformerException, MalformedURLException,
            SAXException, ParserConfigurationException, IOException {
        System.out
                .println("--- handle the XML file thru EchoContentHandler ---");
        runEchoHandler();

        System.out.println("--- filter the XML file thru CounterFilter ---");
        runCounterFilterAndEchoHandler();

        System.out
                .println("--- filter the XML file thru TextExtractionFilter ---");
        runTextExtractionFilter(inputFile);

        System.out
                .println("--- filter the valid XML file thru TextExtractionFilter ---");
        runTextExtractionFilter(inputFileWithDTD);

        System.out.println("--- done ---");
    }

    /**
     * @param args
     * @throws TransformerException 
     * @throws FileNotFoundException 
     */
    public static void main(String[] args) throws Exception {

        Demo demo = new Demo();
        demo.runDemo();
    }

}
